@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.101_02';
+our $VERSION = '0.102_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Jul 29 21:24:59 2018 GMT
+# on Thu Aug  9 12:29:34 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1748,7 +1748,7 @@ __PACKAGE__->status( add => 25285, iridium => 'S', 'Iridium 62', '' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
 __PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
-__PACKAGE__->status( add => 25289, iridium => 'S', 'Iridium 66', '' );
+__PACKAGE__->status( add => 25289, iridium => '-', 'Iridium 66', 'Tumbling' );
 __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-07-02' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 
 # Summary:
 # Operational [+]: 17
-#       Spare [S]: 15
-#    Tumbling [-]: 37
+#       Spare [S]: 14
+#    Tumbling [-]: 38
 #     Decayed [D]: 28
 
 1;
